==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_entities/equiplinearref_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.equiplinearref_001;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.equiplinearref_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.equiplinearref_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link EquipLinearRef }
     * 
     */
    public EquipLinearRef createEquipLinearRef() {
        return new EquipLinearRef();
    }

    /**
     * Create an instance of {@link OverviewDetails }
     * 
     */
    public OverviewDetails createOverviewDetails() {
        return new OverviewDetails();
    }

    /**
     * Create an instance of {@link OffsetandSizeDetails }
     * 
     */
    public OffsetandSizeDetails createOffsetandSizeDetails() {
        return new OffsetandSizeDetails();
    }

    /**
     * Create an instance of {@link SourceDetails }
     * 
     */
    public SourceDetails createSourceDetails() {
        return new SourceDetails();
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/equiplinearref_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.equiplinearref_001;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.equiplinearref_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.equiplinearref_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link EquipLinearRef }
     * 
     * @return
     *     the new instance of {@link EquipLinearRef }
     */
    public EquipLinearRef createEquipLinearRef() {
        return new EquipLinearRef();
    }

    /**
     * Create an instance of {@link OverviewDetails }
     * 
     * @return
     *     the new instance of {@link OverviewDetails }
     */
    public OverviewDetails createOverviewDetails() {
        return new OverviewDetails();
    }

    /**
     * Create an instance of {@link OffsetandSizeDetails }
     * 
     * @return
     *     the new instance of {@link OffsetandSizeDetails }
     */
    public OffsetandSizeDetails createOffsetandSizeDetails() {
        return new OffsetandSizeDetails();
    }

    /**
     * Create an instance of {@link SourceDetails }
     * 
     * @return
     *     the new instance of {@link SourceDetails }
     */
    public SourceDetails createSourceDetails() {
        return new SourceDetails();
    }

}
